==> rubix-1.0.5.tar.bz2: rubix-1.0.5/messages.h <==
/* This is the list of all strings appearing in menus */
/* you just have to localize this !! */

#ifdef ENGLISH

char help_msg[] =
"rubix\n\n"
"        by Sed (sed@free.fr)\n" 
"        and Jean-Pierre Demailly(demailly.ujf-grenoble.fr\n\n"
"Usage : rubix [-i(nit)] [-v(ersion)] [-h(elp)]\n"
"              [-font <spec>] [-width w] [-height h] [-edge <dim>]\n"
"              [-color <face> <val>] (face=ABCDEF,I,0,1,2 / val = #RRGGBB)\n"
"              [-output <format>] [-load <saved cube>]\n"
"where the output type is one of : 0=position, 1=numeric, 2=generators\n\n"
"Commands within the game :\n"
"        Keys a,b,c,d,e,f or A,B,C,D,E,F rotate corresponding faces.\n"
"        The cube can also be moved with the mouse:\n"
"        - mouse moves rotate the whole cube.\n"
"        - mouse clicks (with button 1 or 3) rotate the faces.\n"  
"        The face to be rotated is marked with a cross.\n"
"        Press <Left arrow> or first mouse button to rotate counterclockwise\n"
"        Press <Right arrow> or third mouse button to rotate clockwise\n"
"        Press <Space> to pause/restart the game\n"
"        <h> to show this help message\n"
"        <i> to reinitialize the cube\n"
"        <l> to show/hide letters on faces\n"  
"        <p> to produce a random permutation of the cube\n"
"        <r> to reset the cube at its home position\n"
"        <s> to save the game to the file \"./rubix.<format>\"\n"
"        <+> to shorten perspective distance\n"
"        <-> to switch to imaginary perspective\n"
"        <*> to change the output format\n"  
"        <!> to use interactive controls\n"  
"        <q> or <Esc> to exit\n\n"
"homepage: http://sed.free.fr/rubix/\n"
"May the penguin be with you.\n\n";

int help_numlines;
int help_maxlen;
char **help_index;

char help1[] = "<Space> Start/Pause";
char help2[] = "h Help";
char help3[] = "! Control";

char control_str[] = "Control";
char close_str[] = "Close";

char *controlwin_str[] = 
  { "Erase", "Select", "Init", "Permute", close_str };

char save_output_str[] = "save output";
char perspective_str[] = "perspecive";
char cube_saved_str[] = "cube saved in";

#endif

==> rubix-1.0.6.tar.bz2: rubix-1.0.6/messages.h <==
/* This is the list of all strings appearing in menus */
/* you just have to localize this !! */

#ifdef ENGLISH

char help_msg[] =
"rubix\n\n"
"        by Sed (sed@free.fr)\n" 
"        and Jean-Pierre Demailly (demailly.ujf-grenoble.fr)\n"
"        and Scott A. Morris (samorris@jomche.org)\n\n"
"Usage : rubix [-i(nit)] [-v(ersion)] [-h(elp)]\n"
"              [-font <spec>] [-width w] [-height h] [-edge <dim>]\n"
"              [-color <face> <val>] (face=ABCDEF,I,0,1,2 / val = #RRGGBB)\n"
"              [-output <format>] [-load <saved cube>]\n"
"where the output type is one of : 0=position, 1=numeric, 2=generators\n\n"
"Commands within the game :\n"
"        Keys a,b,c,d,e,f or A,B,C,D,E,F rotate corresponding faces.\n"
"        The cube can also be moved with the mouse:\n"
"        - mouse moves rotate the whole cube.\n"
"        - mouse clicks (with button 1 or 3) rotate the faces.\n"  
"        The face to be rotated is marked with a cross.\n"
"        Press <Left arrow> or first mouse button to rotate counterclockwise\n"
"        Press <Right arrow> or third mouse button to rotate clockwise\n"
"        Press <Space> to pause/restart the game\n"
"        <h> to show this help message\n"
"        <i> to reinitialize the cube\n"
"        <l> to show/hide letters on faces\n"  
"        <p> to produce a random permutation of the cube\n"
"        <r> to reset the cube at its home position\n"
"        <s> to save the game to the file \"./rubix.<format>\"\n"
"        <+> to shorten perspective distance\n"
"        <-> to switch to imaginary perspective\n"
"        <*> to change the output format\n"  
"        <!> to use interactive controls\n"  
"        <q> or <Esc> to exit\n\n"
"homepage: http://sed.free.fr/rubix/\n"
"May the penguin be with you.\n\n";

int help_numlines;
int help_maxlen;
char **help_index;

char help1[] = "<Space> Start/Pause";
char help2[] = "h Help";
char help3[] = "! Control";

char control_str[] = "Control";
char close_str[] = "Close";

char *controlwin_str[] = 
  { "Erase", "Select", "Init", "Permute", close_str };

char save_output_str[] = "save output";
char perspective_str[] = "perspecive";
char cube_saved_str[] = "cube saved in";

#endif
